from .gno_gen_stopwords import gno_generalstopwords
from .gno_gen_stopwords import gno_generalstopwords_cn
from .gno_name_stopwords import gno_inpersonname_remove
from .gno_name_stopwords import gno_honorifics_remove
from .gno_coname_stopwords import gno_inconame_stopwords

def joke():
    return (u'simi lan test test.')